==> hestia_earth_earth_engine-0.0.2-py3-none-any.whl: hestia_earth/earth_engine/gadm/utils.py <==
import ee

from hestia_earth.earth_engine.utils import get_param, get_required_param, get_fields_from_params
from hestia_earth.earth_engine.gee_utils import (
    rename_field, clean_collection, aggregate_by_area, data_from_raster, data_from_raster_by_period, clip_collection,
    defaut_scale
)

DEFAULT_SCALE = 30
DEFAULT_YEAR = 2000


def _data_from_vector(region: ee.FeatureCollection, collection: str, params: dict):
    fields = get_fields_from_params(params)
    reducer = get_param(params, 'reducer', 'first')
    collection = ee.FeatureCollection(collection).filterBounds(region)
    return aggregate_by_area(clip_collection(collection, region.geometry()), fields, reducer)


def _data_from_raster(region: ee.FeatureCollection, collection: str, params: dict):
    image = ee.Image(collection)
    scale = int(get_param(params, 'scale', defaut_scale(image, default=DEFAULT_SCALE)))
    reducer = get_param(params, 'reducer', 'mean')
    fields = get_fields_from_params(params)
    field = fields[0] if len(fields) == 1 else None
    data = data_from_raster(image.clip(region), region, reducer, scale, False)
    return clean_collection(data.map(rename_field(reducer, field)) if field else data)


def _data_from_raster_by_period(region: ee.FeatureCollection, collection: str, params: dict):
    image = ee.ImageCollection(collection)
    band_name = get_required_param(params, 'band_name')
    scale = int(get_param(params, 'scale', DEFAULT_SCALE))
    reducer = get_param(params, 'reducer', 'mean')
    reducer_regions = get_param(params, 'reducer_regions', 'mean')
    year = str(get_param(params, 'year', DEFAULT_YEAR))
    start_date = get_param(params, 'start_date', f"{year}-01-01")
    end_date = get_param(params, 'end_date', f"{year}-12-31")
    fields = get_fields_from_params(params)
    field = fields[0] if len(fields) == 1 else None
    data = data_from_raster_by_period(image, region, reducer, reducer_regions,
                                      scale, band_name, start_date, end_date, False)
    return clean_collection(data.map(rename_field(reducer_regions, field)) if field else data)


DATA_BY_TYPE = {
    'vector': _data_from_vector,
    'raster': _data_from_raster,
    'raster_by_period': _data_from_raster_by_period
}


def load(collection: str, ee_type: str, region: ee.FeatureCollection, params: dict):
    return DATA_BY_TYPE[ee_type](region, collection, params)

==> hestia_earth_earth_engine-0.1.1-py3-none-any.whl: hestia_earth/earth_engine/gadm/utils.py <==
import ee

from hestia_earth.earth_engine.utils import get_param, get_required_param, get_fields_from_params
from hestia_earth.earth_engine.gee_utils import (
    rename_field, clean_collection, aggregate_by_area, data_from_raster, data_from_raster_by_period, clip_collection,
    defaut_scale
)

DEFAULT_SCALE = 30
DEFAULT_YEAR = 2000


def _data_from_vector(region: ee.FeatureCollection, collection: str, params: dict):
    fields = get_fields_from_params(params)
    reducer = get_param(params, 'reducer', 'first')
    collection = ee.FeatureCollection(collection).filterBounds(region)
    return aggregate_by_area(clip_collection(collection, region.geometry()), fields, reducer)


def _data_from_raster(region: ee.FeatureCollection, collection: str, params: dict):
    image = ee.Image(collection)
    scale = int(get_param(params, 'scale', defaut_scale(image, default=DEFAULT_SCALE)))
    reducer = get_param(params, 'reducer', 'mean')
    fields = get_fields_from_params(params)
    field = fields[0] if len(fields) == 1 else None
    data = data_from_raster(image.clip(region), region, reducer, scale, False)
    return clean_collection(data.map(rename_field(reducer, field)) if field else data)


def _data_from_raster_by_period(region: ee.FeatureCollection, collection: str, params: dict):
    image = ee.ImageCollection(collection)
    band_name = get_required_param(params, 'band_name')
    scale = int(get_param(params, 'scale', DEFAULT_SCALE))
    reducer = get_param(params, 'reducer', 'mean')
    reducer_regions = get_param(params, 'reducer_regions', 'mean')
    year = str(get_param(params, 'year', DEFAULT_YEAR))
    start_date = get_param(params, 'start_date', f"{year}-01-01")
    end_date = get_param(params, 'end_date', f"{year}-12-31")
    reducer_years = get_param(params, 'reducer_years')
    fields = get_fields_from_params(params)
    field = fields[0] if len(fields) == 1 else None
    data = data_from_raster_by_period(
        image, region, reducer, reducer_regions, scale, band_name, start_date, end_date, False,
        reducer_years=reducer_years
    )
    return clean_collection(data.map(rename_field(reducer_regions, field)) if field else data)


DATA_BY_TYPE = {
    'vector': _data_from_vector,
    'raster': _data_from_raster,
    'raster_by_period': _data_from_raster_by_period
}


def load(collection: str, ee_type: str, region: ee.FeatureCollection, params: dict):
    return DATA_BY_TYPE[ee_type](region, collection, params)
